# Vercel Terraform Provider

- Website: https://www.terraform.io
- Documentation: https://registry.terraform.io/providers/vercel/vercel/latest

## Requirements

- [Terraform](https://www.terraform.io/downloads.html) 1.1 or higher
- [Go](https://golang.org/doc/install) 1.17 (to build the provider plugin)
- [Task](https://taskfile.dev) v3 (to run Taskfile commands)

## Building The Provider

Clone repository locally and run

```sh
$ task build
```

## Developing the Provider

If you wish to work on the provider, you'll first need [Go](http://www.golang.org) installed on your machine (version 1.17+ is _required_).

To compile the provider, run `task build`. This will build the provider and put the provider binary in the repository root.

In addition, you can run `task install` to set up a developer overrides in your ~/.terraformrc. This will then allow you
to use your locally built provider binary.

When you are finished using a local version of the provider, running `task uninstall` will remove _all_ developer
overrides.

- HashiCorp - [Development Overrides for Provider developers](https://www.terraform.io/docs/cli/config/config-file.html#development-overrides-for-provider-developers).

## Testing

In order to test the provider, you can simply run `task test`.

_Note:_ This runs acceptance tests that will create real resources. You should expect that the full acceptance test suite will take some time to run.

The acceptance tests require a `VERCEL_API_TOKEN` (which can be generated [here](https://vercel.com/account/tokens), and
a `VERCEL_TERRAFORM_TESTING_TEAM` (which should be a Vercel team_id where resources can be created and destroyed)
environment variable set.

```sh
$ task test
```

In order to run the tests with extra debugging context, prefix with `TF_LOG` (see the [terraform documentation](https://www.terraform.io/docs/internals/debugging.html) for details).

```sh
$ TF_LOG=trace task test
```

## Building The Documentation

The documentation is autogenerated from Description fields within the provider, and the `examples` directory.
Building the documentation generates markdown in the `docs` folder, ready for deployment to Hashicorp.

- To view the documentation:
  Paste `/docs` Markdown file content into https://registry.terraform.io/tools/doc-preview
